@@ -73,7 +73,7 @@ class cubetimer():
 
 	def settings(self):
 		#Laden der gespeicherten Werte
-		f = open("~/.config/cubetimerqml/settings.cfg")
+		f = open("~/.config/cubetimerqml.cfg")
 		l = pickle.load(f)
 
 		#Stopuhr-Setting lesen und bestimmen
@@ -194,7 +194,7 @@ class cubetimer():
 		#Die Zeiten sollen natürlich nicht gespeichert werden, wenn der User im Stopuhr Modus ist!		
 		if self.stopwatchmode == False:
 			#Laden der gespeicherten Daten
-			f = open("~/.config/cubetimerqml/settings.cfg")
+			f = open("~/.config/cubetimerqml.cfg")
 			l = pickle.load(f)
 
 			#Einlesen der Zeiten und Berechnung! "last" ist die letzte Zeit, der Durchschnitt ergibt sich aus allen jemals gespielten Zeiten.
@@ -212,7 +212,7 @@ class cubetimer():
 				l["record"] = zeit
 
 			#Speichern der Daten
-			f = open("~/.config/cubetimerqml/settings.cfg", "w")
+			f = open("~/.config/cubetimerqml.cfg", "w")
 			pickle.dump(l,f)
 
 		else:
@@ -238,13 +238,13 @@ class cubetimer():
 			self.root.stopwatchsetting(str(self.stopwatchmode))
 
 		#Laden der gespeicherten Daten
-		f = open("~/.config/cubetimerqml/settings.cfg")
+		f = open("~/.config/cubetimerqml.cfg")
 		l = pickle.load(f)
 
 		l["stopwatch"] = self.stopwatchmode
 		
 		#Speichern der Daten
-		f = open("~/.config/cubetimerqml/settings.cfg", "w")
+		f = open("~/.config/cubetimerqml.cfg", "w")
 		pickle.dump(l,f)
 
 #--------------------------------------------------------------------------------------------------
@@ -258,13 +258,13 @@ class cubetimer():
 			self.root.inspectionsetting(str(self.inspectionmode))
 
 		#Laden der gespeicherten Daten
-		f = open("~/.config/cubetimerqml/settings.cfg")
+		f = open("~/.config/cubetimerqml.cfg")
 		l = pickle.load(f)
 
 		l["inspection"] = self.inspectionmode
 		
 		#Speichern der Daten
-		f = open("~/.config/cubetimerqml/settings.cfg", "w")
+		f = open("~/.config/cubetimerqml.cfg", "w")
 		pickle.dump(l,f)
 
 	def update_wait_time(self):
